/*
 * Copyright 2003-2018 The Music Player Daemon Project
 * http://www.musicpd.org
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */

#include "config.h"
#include "Init.hxx"
#include "Collate.hxx"
#include "util/RuntimeError.hxx"

#include <unicode/uclean.h>

void
IcuInit()
{
	UErrorCode code = U_ZERO_ERROR;
	u_init(&code);
	if (U_FAILURE(code))
		throw FormatRuntimeError("u_init() failed: %s",
					 u_errorName(code));

	IcuCollateInit();
}

void
IcuFinish() noexcept
{
	IcuCollateFinish();

	u_cleanup();
}
